@@ -1,9 +1,10 @@
 import os
 
+from nemdata.constants import constants
 from nemdata.downloader import download
 from nemdata.loader import load
 
 home = os.path.join(os.path.expanduser("~"), "nem-data")
 
 
-__all__ = ["download", "load"]
+__all__ = ["constants", "download", "load"]
