@@ -12,6 +12,7 @@ def concat(
     pkg: dict,
     start: typing.Union[str, None] = None,
     end: typing.Union[str, None] = None,
+    columns: typing.Union[list[str], None] = None,
 ) -> dict:
     data = [p for p in report_id.glob("**/clean.parquet")]
 
@@ -27,17 +28,21 @@ def concat(
 
     dates = [pd.Timestamp(d.parent.name) for d in data]
     data = [d for d, date in zip(data, dates) if (date >= start) and (date <= end)]
-    data = [pd.read_parquet(p) for p in data]
+    data = [pd.read_parquet(p, columns=columns) for p in data]
     df = pd.concat(data, axis=0)
     pkg[report_id.name] = df.sort_values("interval-start")
     return pkg
 
 
-def concat_trading_price(report_id: pathlib.Path, pkg: dict) -> dict:
+def concat_trading_price(
+    report_id: pathlib.Path,
+    pkg: dict,
+    columns: typing.Union[list[str], None] = None,
+) -> dict:
     fis = [p for p in report_id.glob("**/clean.parquet")]
     datas = []
     for fi in fis:
-        data = pd.read_parquet(fi)
+        data = pd.read_parquet(fi, columns=columns)
         for region in data["REGIONID"].unique():
             raw = data[data["REGIONID"] == region]
             raw = raw.set_index("interval-start").sort_index()
@@ -57,6 +62,7 @@ def concat_trading_price(report_id: pathlib.Path, pkg: dict) -> dict:
 def load(
     desired_reports: typing.Union[list, str, None] = None,
     *,
+    columns: typing.Union[list[str], None] = None,
     base_directory: pathlib.Path = DEFAULT_BASE_DIR,
 ) -> dict:
     pkg: dict = {}
@@ -78,8 +84,8 @@ def load(
 
     for report_id in report_ids:
         if report_id.name == "trading-price":
-            pkg = concat_trading_price(report_id, pkg)
+            pkg = concat_trading_price(report_id, pkg, columns=columns)
         else:
-            pkg = concat(report_id, pkg)
+            pkg = concat(report_id, pkg, columns=columns)
 
     return pkg
